==> converter-0.2.0.tar.gz: test/quantities/area_testcase.dart <==
import 'package:converter/converter.dart';

final Map<String, dynamic> areaConverter = <String, dynamic>{
  'testCases': <Map<String, dynamic>>[
    <String, dynamic>{
      'quantity': Area.si(49),
      'magnitudeInSI': 49,
      'magnitudeIn': <String, num>{
        'm2': 49,
        'dm2': 4900,
        'cm2': 4.9e5,
        'mm2': 4.9e7,
        'µm2': 4.9e13,
        'dam2': 0.49,
        'hm2': 0.0049,
        'ha': 0.0049,
        'km2': 4.9e-5,
        'Mm2': 4.9e-11,
        'in2': 7.595015e4,
        'ft2': 527.431610,
        'mi2': 1.891901e-5,
        'ac': 0.01210816,
      },
    },
    <String, dynamic>{
      'quantity': Area(121, 'µm2'),
      'magnitudeInSI': 1.21e-10,
      'magnitudeIn': <String, num>{
        'm2': 1.21e-10,
        'dm2': 1.21e-8,
        'cm2': 1.21e-6,
        'mm2': 1.21e-4,
        'µm2': 121,
        'dam2': 1.21e-12,
        'hm2': 1.21e-14,
        'ha': 1.21e-14,
        'km2': 1.21e-16,
        'Mm2': 1.21e-22,
        'in2': 1.875504e-7,
        'ft2': 1.302433e-9,
        'mi2': 4.671836e-17,
        'ac': 2.989975e-14,
      },
    },
    <String, dynamic>{
      'quantity': Area(169, 'Mm2'),
      'magnitudeInSI': 1.69e14,
      'magnitudeIn': <String, num>{
        'm2': 1.69e14,
        'dm2': 1.69e16,
        'cm2': 1.69e18,
        'mm2': 1.69e20,
        'µm2': 1.69e26,
        'dam2': 1.69e12,
        'hm2': 1.69e10,
        'ha': 1.69e10,
        'km2': 1.69e8,
        'Mm2': 169,
        'in2': 2.619505e17,
        'ft2': 1.819101e15,
        'mi2': 6.525126e7,
        'ac': 4.176081e10,
      },
    },
  ],
};

==> converter-0.3.4.tar.gz: test/quantities/area_testcase.dart <==
import 'package:converter/converter.dart';

final Map<String, dynamic> areaConverter = <String, dynamic>{
  'testCases': <Map<String, dynamic>>[
    <String, dynamic>{
      'quantity': Area.si(49),
      'siValue': 49,
      'valueIn': <String, num>{
        'm2': 49,
        'dm2': 4900,
        'cm2': 4.9e5,
        'mm2': 4.9e7,
        'µm2': 4.9e13,
        'dam2': 0.49,
        'hm2': 0.0049,
        'ha': 0.0049,
        'km2': 4.9e-5,
        'Mm2': 4.9e-11,
        'in2': 7.595015e4,
        'ft2': 527.431610,
        'mi2': 1.891901e-5,
        'ac': 0.01210816,
      },
    },
    <String, dynamic>{
      'quantity': Area(121, 'µm2'),
      'siValue': 1.21e-10,
      'valueIn': <String, num>{
        'm2': 1.21e-10,
        'dm2': 1.21e-8,
        'cm2': 1.21e-6,
        'mm2': 1.21e-4,
        'µm2': 121,
        'dam2': 1.21e-12,
        'hm2': 1.21e-14,
        'ha': 1.21e-14,
        'km2': 1.21e-16,
        'Mm2': 1.21e-22,
        'in2': 1.875504e-7,
        'ft2': 1.302433e-9,
        'mi2': 4.671836e-17,
        'ac': 2.989975e-14,
      },
    },
    <String, dynamic>{
      'quantity': Area(169, 'Mm2'),
      'siValue': 1.69e14,
      'valueIn': <String, num>{
        'm2': 1.69e14,
        'dm2': 1.69e16,
        'cm2': 1.69e18,
        'mm2': 1.69e20,
        'µm2': 1.69e26,
        'dam2': 1.69e12,
        'hm2': 1.69e10,
        'ha': 1.69e10,
        'km2': 1.69e8,
        'Mm2': 169,
        'in2': 2.619505e17,
        'ft2': 1.819101e15,
        'mi2': 6.525126e7,
        'ac': 4.176081e10,
      },
    },
  ],
};
